@@ -3,13 +3,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect musical modal functions
 
-our $VERSION = '0.0315';
+our $VERSION = '0.0316';
 
-use Moo;
 use strictures 2;
 use AI::Prolog ();
 use Carp qw(croak);
 use MIDI::Util qw(midi_format);
+use Moo;
 use Music::Note ();
 use Music::Scales qw(get_scale_notes);
 use namespace::clean;
@@ -241,7 +241,7 @@ Music::ModalFunction - Inspect musical modal functions
 
 =head1 VERSION
 
-version 0.0315
+version 0.0316
 
 =head1 SYNOPSIS
 
@@ -256,21 +256,23 @@ version 0.0315
   my $results = $m->chord_key;
   # [['chord_key','d','maj','g','ionian','dominant','r_V'],
   #  ['chord_key','d','maj','g','lydian','dominant','r_V']]
+  # So the answers are G Ionian and G Lydian.
 
   # In what mode(s) can a Gmaj chord function as a subdominant pivot chord?
   $m = Music::ModalFunction->new(
     chord_note   => 'g',
     chord        => 'maj',
-    mode_note    => 'c',
     key_function => 'subdominant',
   );
   $results = $m->pivot_chord_keys;
-  # [['pivot_chord_keys','g','maj','c','ionian','dominant','d','dorian','subdominant','r_IV'],
-  #  ['pivot_chord_keys','g','maj','c','ionian','dominant','d','ionian','subdominant','r_IV'],
-  #  ['pivot_chord_keys','g','maj','c','ionian','dominant','d','mixolydian','subdominant','r_IV'],
-  #  ['pivot_chord_keys','g','maj','c','lydian','dominant','d','dorian','subdominant','r_IV'],
-  #  ['pivot_chord_keys','g','maj','c','lydian','dominant','d','ionian','subdominant','r_IV'],
-  #  ['pivot_chord_keys','g','maj','c','lydian','dominant','d','mixolydian','subdominant','r_IV']]
+  # [[ 'pivot_chord_keys', 'g', 'maj', 'c', 'ionian', 'dominant', 'r_V', 'd', 'dorian', 'subdominant', 'r_IV' ],
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'c', 'ionian', 'dominant', 'r_V', 'd', 'ionian', 'subdominant', 'r_IV' ],
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'c', 'ionian', 'dominant', 'r_V', 'd', 'mixolydian', 'subdominant', 'r_IV' ],
+  #  ...
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'b', 'phrygian', 'submediant', 'r_VI', 'd', 'dorian', 'subdominant', 'r_IV' ],
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'b', 'phrygian', 'submediant', 'r_VI', 'd', 'ionian', 'subdominant', 'r_IV' ],
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'b', 'phrygian', 'submediant', 'r_VI', 'd', 'mixolydian', 'subdominant', 'r_IV' ]]
+  # Inspecting the result lists, we see that the answers are D Dorian, D Ionian, and D Mixolydian.
 
 =head1 DESCRIPTION
 
@@ -279,6 +281,10 @@ Prolog facts and rules that bind notes, chords, modes, keys and
 diatonic functionality. In this database, the facts are all called
 C<chord_key> and the rules are C<pivot_chord_keys> and C<roman_key>.
 
+Wikipedia puts it this way, "A common chord, in the theory of harmony,
+is a chord that is diatonic to more than one key or, in other words,
+is common to (shared by) two keys."
+
 To bind a value to a fact or rule argument, declare it in the object
 constructor. Unbound arguments will return all the possible values
 that make the query true.
@@ -417,6 +423,8 @@ L<https://en.wikipedia.org/wiki/Prolog>
 
 L<https://en.wikipedia.org/wiki/Common_chord_(music)>
 
+L<https://en.wikipedia.org/wiki/Closely_related_key>
+
 L<https://ology.github.io/2023/06/05/querying-a-music-theory-database/>
 is the write-up about using this module
 
